
#  Paramétrage des bulletins de notes 
Ces réglages permettent de configurer la présentation des relevés de notes au format PDF.

Le bulletin est constitué de plusieurs zones:

 * Le titre;
 * le tableau des notes;
 * les absences et appréciations (immédiatement sous le tableau des notes; les absences ne sont mentionnés que si la case "Indiquer les absences sur les bulletins" est cochée);
 * la situation de l'étudiant (inscription, décision de jury, validations d'UE);
 * la signature de gauche et celle de droite;
 * le pied de page.
 
Le contenu et la présentation des zones titre, situation et signatures sont paramétrables à l'aide de formats utilisant un balisage XML assez simple.


##  Marges et position du pied de page 
Les bulletins sont formattés pour du papier A4.

Les marges sont réglables via les valeurs dans la section "Marges additionnelles des bulletins". Ces valeurs s'ajoutent aux marges par défaut qui sont assez étroites.

Le pied de page (*Edité par ScoDoc le ...*) n'est pas affecté par le réglage des marges, et est positionné à l'aide des paramètres "Position horizontale du pied de page pdf" (resp. verticale) dans la section "Mise en forme des documents PDF". Ces valeurs affectent tous les documents PDF générés par ScoDoc. 


##  Valeurs remplacées 
Dans les formats, les balises de la forme `%(X)s` sont remplacées par la valeur (texte) de la variable X si elle existe. Les variables définies apportent différentes informations:


###  Préférences 
Toutes les préférences pour le semestre considéré (ou définies globalement) sont utilisables par leur nom.
Voir la liste complète sur [NomsPreferences](NomsPreferences.md).



###  Informations sur le semestre 
Variable | Valeur
---------|-------
titre_num | Le titre du semestre
titremois | idem avec dates début et fin
annee | L'année de début du semestre
anneescolaire | L'année scolaire (par ex. "2009 - 2010")
date_debut | 01/09/2008
date_fin | 05/07/2009
responsable | Nom du responsable du semestre (dir. des études)


###  Informations sur l'étudiant 
Variable | Valeur (exemple)
---------|-------
nom| DUPONT
prenom| PIERRE
sexe| M.
nomprenom| M. Pierre DUPONT
situation| phrase expliquant la situation de l'étudiant (inscription, décisions de jury)
demission| "DEMISSION" ou vide
inscription| phrase décrivant l'inscription ("ancien")
date_inscription| jj/mm/aaaa
date_demission || (vide si pas demission)
descr_inscription| "Inscrit" ou "Pas inscrit[e]"
descr_demission || "Démission le 01/02/2000" ou vide si pas de démissio
decision_jury   ||  "Validé", "Ajourné", ... (code semestre
descr_decision_jury| "Décision jury: Validé" (une phrase
decisions_ue      || noms (acronymes) des UE validées, séparées par des virgules.
descr_decisions_ue|| " UE acquises: UE1, UE2", ou vide si pas de dec. ou paramètrage
mention| Mention, calculée d'après la moyenne générale
 |
**Absences:** |
nbabs| nombre d'absences (en demi-journées)
nbabsjust| nombre d'abs. justifiées
 |
**Autres champs:**|
date_naissance | date, au format jj/mm/aaaa 
lieu_naissance | format libre 
domicile | adresse, format libre
codepostaldomicile | 
codelycee | code national français 
 |
**Groupes:**| 
groupes | indique les groupes auxquels appartient l'étudiant dans le semestre
group_0 | nom du groupe principal (1ère partition)
group_<n> | nom du group de la n-ième partition


###  Autres informations 
Variable | &nbsp;
---------|-------
date_dmy | date courante, au format jj/mm/aaaa
date_iso | date courante, au format aaaa-mm-jj



##  Balises XML utilisées dans les formats 
Le balisage XML est celui de [ReportLab](http://www.reportlab.com/) (intra-paragraph markup, voir page 70 du [guide utilisateur](http://www.reportlab.com/docs/reportlab-userguide.pdf)). La balise `<img>` n'est pas utilisable.


###  Logos 
Une balise supplémentaire est interprétée par ScoDoc pour insérer des logos (images).

Les logos doivent être des images au format JPEG (extension `.jpg` uniquement), placées dans le répertoire `.../logos/`, et nommées `logo_xxx.jpg`.

La balise `<logo name="xxx" width="44mm" height="22mm" valign="+5mm"/>`, placée dans un paragraphe, insère alors le logo `xxx` avec les dimensions indiquées. Le paramètre `valign` règle le positionnement vertical par rapport à la ligne de texte courante.

Voir un exemple d'utilisation plus bas.


##  Exemples 
###  Exemple 1: Bulletins par défaut 
Les bulletins édités par défaut sont obtenus avec:

 * Paragraphe de titre:
```
<para fontSize="14" align="center">
<b>%(UnivName)s</b>
</para>
<para fontSize="16" align="center" spaceBefore="2mm">
<b>%(InstituteName)s</b>
</para>
<para fontSize="16" align="center" spaceBefore="4mm">
<b>RELEVÉ DE NOTES</b>
</para>

<para fontSize="15" spaceBefore="3mm">
%(nomprenom)s <b>%(demission)s</b>
</para>

<para fontSize="14" spaceBefore="3mm">
Formation: %(titre_num)s</para>
<para fontSize="14" spaceBefore="2mm">
Année scolaire: %(anneescolaire)s
</para>
```

 * Paragraphe sous table note:
```
<para spaceBefore="5mm" fontSize="14"><i>%(situation)s</i></para>
```

 * Signature de gauche
```
<para>La direction des études
<br/>
%(responsable)s
</para>
```

 * Signature de droite:
```
<para>Le chef de département
<br/>
%(ChiefDeptName)s
</para>
```



###  Exemple 2: ancien bulletins 
Les bulletins édités par défaut avant le 20/9/2009 étaient obtenus avec:

 * Paragraphe de titre:
```
<para fontSize="16">
<b>%(UnivName)s</b>
</para><para fontSize="14" spaceBefore="2mm">
<b>%(titre_num)s %(annee)s</b></para>
<para fontSize="14" spaceBefore="2mm">
<b>Relevé de notes de <i>%(nomprenom)s</i> %(demission)s</b>
</para>
```

 * Paragraphe sous table note:
```
<para spaceBefore="5mm" fontSize="14"><i>%(situation)s</i></para>
```

 * Signature de gauche
```
<para>La direction des études
<br/>
%(responsable)s
</para>
```

 * Signature de droite:
```
<para>Le chef de département
<br/>
%(ChiefDeptName)s
</para>
```


###  Exemple 3: en-tête avec logo 
Même structure que le premier exemple, avec un logo. Notez que les dimensions du logo (en mm ou cm) doivent avoir le même rapport (hauteur/largeur) que l'image utilisée, sans quoi l'apparence est déformée.

 * Paragraphe de titre:
```
<para fontSize="16" align="center" spaceBefore="2mm">
<b>%(InstituteName)s</b>
</para>
<para fontSize="16" align="center" spaceBefore="4mm">
<b>RELEVÉ DE NOTES</b>
</para>

<para fontSize="15" spaceBefore="3mm">
<logo name="header" width="44mm" height="22mm" valign="+5mm"/>
<br/>
%(nomprenom)s <b>%(demission)s</b>
</para>

<para fontSize="14" spaceBefore="3mm">
Formation: %(titre_num)s</para>
<para fontSize="14" spaceBefore="2mm">
Année scolaire: %(anneescolaire)s
</para>
```

